package com.psbc.cpsp.eden.mapper.asset;

import com.psbc.cpsp.eden.common.entity.AssetClassification;
import com.psbc.cpsp.eden.common.vo.TreeNode;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import java.util.List;
import java.util.Date;

/**
 * 资产分类Mapper接口
 */
@Mapper
public interface AssetClassificationMapper {
    /**
     * 新增资产分类
     *
     * @param classification 资产分类信息
     * @return 影响行数
     */
    int insert(AssetClassification classification);

    /**
     * 修改资产分类
     *
     * @param classification 资产分类信息
     * @return 影响行数
     */
    int update(AssetClassification classification);

    /**
     * 更新资产分类状态
     *
     * @param id            资产分类ID
     * @param status        状态
     * @param lastModUserId 最后修改人ID
     * @param lastModTime   最后修改时间
     * @param tenantId      租户ID
     * @return 影响行数
     */
    int updateStatus(@Param("id") String id, @Param("status") String status,
            @Param("lastModUserId") String lastModUserId,
            @Param("lastModTime") Date lastModTime,
            @Param("tenantId") String tenantId);

    /**
     * 根据ID查询资产分类详情
     *
     * @param id       资产分类ID
     * @param tenantId 租户ID
     * @return 资产分类信息
     */
    AssetClassification selectById(@Param("id") String id, @Param("tenantId") String tenantId);

    /**
     * 查询资产分类列表
     *
     * @param classification 资产分类信息
     * @return 资产分类集合
     */
    List<AssetClassification> selectList(AssetClassification classification);

    /**
     * 逻辑删除资产分类
     *
     * @param id            资产分类ID
     * @param lastModUserId 最后修改人ID
     * @param tenantId      租户ID
     * @return 影响行数
     */
    int deleteById(@Param("id") String id, @Param("lastModUserId") String lastModUserId,
            @Param("tenantId") String tenantId);

    /**
     * 批量逻辑删除资产分类
     *
     * @param ids           资产分类ID集合
     * @param lastModUserId 最后修改人ID
     * @param tenantId      租户ID
     * @return 影响行数
     */
    int deleteBatchIds(@Param("ids") List<String> ids, @Param("lastModUserId") String lastModUserId,
            @Param("tenantId") String tenantId);

    /**
     * 查询资产分类树结构
     *
     * @param classification 资产分类信息
     * @return 树节点集合
     */
    List<TreeNode> selectTree(AssetClassification classification);

    /**
     * 根据父ID查询所有子节点（包含子节点的子节点）
     *
     * @param parentId 父节点ID
     * @param tenantId 租户ID
     * @return 子节点集合
     */
    List<AssetClassification> selectChildrenByParentId(@Param("parentId") String parentId,
            @Param("tenantId") String tenantId);

    /**
     * 校验分类编码是否唯一
     *
     * @param classificationCode 分类编码
     * @param id                 分类ID
     * @param tenantId           租户ID
     * @return 结果
     */
    int checkCodeUnique(@Param("classificationCode") String classificationCode, @Param("id") String id,
            @Param("tenantId") String tenantId);

    /**
     * 根据分类名称查询分类ID
     *
     * @param classificationName 分类名称
     * @return 分类ID
     */
    Integer selectIdByName(@Param("classificationName") String classificationName);

    /**
     * 校验分类名称是否存在
     *
     * @param classificationName 分类名称
     * @return 结果
     */
    int checkNameExists(@Param("classificationName") String classificationName);
}