package com.psbc.cpsp.eden.mapper.asset;

import com.psbc.cpsp.eden.common.entity.AssetLocation;
import com.psbc.cpsp.eden.common.vo.TreeNode;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import java.util.List;
import java.util.Date;

/**
 * 资产位置Mapper接口
 */
@Mapper
public interface AssetLocationMapper {
        /**
         * 新增资产位置
         *
         * @param location 资产位置信息
         * @return 影响行数
         */
        int insert(AssetLocation location);

        /**
         * 修改资产位置
         *
         * @param location 资产位置信息
         * @return 影响行数
         */
        int update(AssetLocation location);

        /**
         * 更新资产位置状态
         *
         * @param id            资产位置ID
         * @param status        状态
         * @param lastModUserId 最后修改人ID
         * @param lastModTime   最后修改时间
         * @param tenantId      租户ID
         * @return 影响行数
         */
        int updateStatus(@Param("id") String id, @Param("status") String status,
                        @Param("lastModUserId") String lastModUserId,
                        @Param("lastModTime") Date lastModTime,
                        @Param("tenantId") String tenantId);

        /**
         * 根据ID查询资产位置详情
         *
         * @param id       资产位置ID
         * @param tenantId 租户ID
         * @return 资产位置信息
         */
        AssetLocation selectById(@Param("id") String id, @Param("tenantId") String tenantId);

        /**
         * 查询资产位置列表
         *
         * @param location 资产位置信息
         * @return 资产位置集合
         */
        List<AssetLocation> selectList(AssetLocation location);

        /**
         * 逻辑删除资产位置
         *
         * @param id            资产位置ID
         * @param lastModUserId 最后修改人ID
         * @param tenantId      租户ID
         * @return 影响行数
         */
        int deleteById(@Param("id") String id, @Param("lastModUserId") String lastModUserId,
                        @Param("tenantId") String tenantId);

        /**
         * 批量逻辑删除资产位置
         *
         * @param ids           资产位置ID集合
         * @param lastModUserId 最后修改人ID
         * @param tenantId      租户ID
         * @return 影响行数
         */
        int deleteBatchIds(@Param("ids") List<String> ids, @Param("lastModUserId") String lastModUserId,
                        @Param("tenantId") String tenantId);

        /**
         * 查询资产位置树结构
         *
         * @param location 资产位置信息
         * @return 树节点集合
         */
        List<TreeNode> selectTree(AssetLocation location);

        /**
         * 根据父ID查询所有子节点（包含子节点的子节点）
         *
         * @param parentId 父节点ID
         * @param tenantId 租户ID
         * @return 子节点集合
         */
        List<AssetLocation> selectChildrenByParentId(@Param("parentId") String parentId,
                        @Param("tenantId") String tenantId);

        /**
         * 校验位置编码是否唯一
         *
         * @param locationCode 位置编码
         * @param id           位置ID
         * @param tenantId     租户ID
         * @return 结果
         */
        int checkCodeUnique(@Param("locationCode") String locationCode, @Param("id") String id,
                        @Param("tenantId") String tenantId);

        /**
         * 根据位置名称查询位置ID
         *
         * @param locationName 位置名称
         * @return 位置ID
         */
        Integer selectIdByName(@Param("locationName") String locationName);
}