package com.psbc.cpsp.eden.service.asset;

import com.psbc.cpsp.eden.common.entity.AssetLocation;
import com.psbc.cpsp.eden.common.vo.TreeNode;
import java.util.List;

/**
 * 资产位置Service接口
 */
public interface IAssetLocationService {
    /**
     * 查询资产位置列表
     *
     * @param location 资产位置信息
     * @return 资产位置集合
     */
    List<AssetLocation> selectList(AssetLocation location);

    /**
     * 查询资产位置树结构
     *
     * @param location 资产位置信息
     * @return 树节点集合
     */
    List<TreeNode> selectTree(AssetLocation location);

    /**
     * 根据父ID查询所有子节点
     *
     * @param parentId 父节点ID
     * @param tenantId 租户ID
     * @return 子节点集合
     */
    List<AssetLocation> selectChildrenByParentId(String parentId, String tenantId);

    /**
     * 根据ID查询资产位置
     *
     * @param id 资产位置ID
     * @return 资产位置信息
     */
    AssetLocation selectById(String id);

    /**
     * 新增资产位置
     *
     * @param location 资产位置信息
     * @return 资产位置信息
     */
    AssetLocation insert(AssetLocation location);

    /**
     * 修改资产位置
     *
     * @param location 资产位置信息
     * @return 资产位置信息
     */
    AssetLocation update(AssetLocation location);

    /**
     * 更新资产位置状态
     *
     * @param id            资产位置ID
     * @param status        状态
     * @param lastModUserId 最后修改人ID
     * @return 是否成功
     */
    boolean updateStatus(String id, String status, String lastModUserId);

    /**
     * 删除资产位置
     *
     * @param id            资产位置ID
     * @param lastModUserId 最后修改人ID
     */
    void deleteById(String id, String lastModUserId);

    /**
     * 批量删除资产位置
     *
     * @param ids           需要删除的数据ID集合
     * @param lastModUserId 最后修改人ID
     */
    void deleteBatchIds(List<String> ids, String lastModUserId);

    /**
     * 校验资产位置编码是否唯一
     *
     * @param location 资产位置信息
     * @return 结果
     */
    boolean checkCodeUnique(AssetLocation location);

    /**
     * 根据位置名称查询位置ID
     *
     * @param locationName 位置名称
     * @return 位置ID
     */
    Integer selectIdByName(String locationName);
}